@@ -21,7 +21,7 @@ class File:
         self.__description__ = '文件相关， 包括读文件，写文件， 下载文件'
         self.base_dir = base_dir
 
-    def read(self, file_name, sheet_name='', read_type='r', dict_name='', to_json=True, **kwargs):
+    def read(self, file_name, sheet_name='', read_type='r', dict_name='', to_json=True, table_sheet=True, **kwargs):
         file_type = file_name.split('.')[-1]
         url = os.path.join(self.base_dir, dict_name, file_name)
         if os.path.exists(url) is False:
@@ -29,8 +29,11 @@ class File:
             return None
         to_string = kwargs.get('to_string')
         if file_type in ['xlsx', 'xls']:
+            table_sheet = kwargs.get('table_sheet')
             data = xlrd.open_workbook(url)
             table = data.sheet_by_name(sheet_name)
+            if table_sheet:
+                return table
             items = []
             ths = table.row_values(0)
             strings = '\t'.join(ths)
@@ -38,7 +41,7 @@ class File:
             nrow = table.nrows
             for i in range(1, nrow):
                 item1 = []
-                item = []
+                item = {}
                 for j in range(0, len(ths)):
                     cell = table.cell_value(i, j)
                     item[ths[j]] = cell
